# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKCommonPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkMinimumMaximumImageCalculatorPython
else:
    import _itkMinimumMaximumImageCalculatorPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkCovariantVectorPython
import itk.vnl_vector_refPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.itkVectorPython
import itk.itkFixedArrayPython
import itk.vnl_matrix_fixedPython
import itk.itkPointPython
import itk.itkIndexPython
import itk.itkOffsetPython
import itk.itkSizePython
import itk.itkImagePython
import itk.itkImageRegionPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkRGBPixelPython
import itk.itkRGBAPixelPython

def itkMinimumMaximumImageCalculatorIF2_New():
    return itkMinimumMaximumImageCalculatorIF2.New()

class itkMinimumMaximumImageCalculatorIF2(itk.ITKCommonBasePython.itkObject):
    r"""Proxy of C++ itkMinimumMaximumImageCalculatorIF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMinimumMaximumImageCalculatorIF2_Pointer"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMinimumMaximumImageCalculatorIF2_Pointer"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIF2_Clone(self)

    def SetImage(self, _arg):
        r"""
        SetImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageF2 const *

        """
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIF2_SetImage(self, _arg)

    def ComputeMinimum(self):
        r"""ComputeMinimum(self)"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIF2_ComputeMinimum(self)

    def ComputeMaximum(self):
        r"""ComputeMaximum(self)"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIF2_ComputeMaximum(self)

    def Compute(self):
        r"""Compute(self)"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIF2_Compute(self)

    def GetMinimum(self):
        r"""GetMinimum(self) -> float"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIF2_GetMinimum(self)

    def GetMaximum(self):
        r"""GetMaximum(self) -> float"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIF2_GetMaximum(self)

    def GetIndexOfMinimum(self):
        r"""GetIndexOfMinimum(self) -> itkIndex2"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIF2_GetIndexOfMinimum(self)

    def GetIndexOfMaximum(self):
        r"""GetIndexOfMaximum(self) -> itkIndex2"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIF2_GetIndexOfMaximum(self)

    def SetRegion(self, region):
        r"""
        SetRegion(self, region)

        Parameters
        ----------
        region: itkImageRegion2 const &

        """
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIF2_SetRegion(self, region)
    __swig_destroy__ = _itkMinimumMaximumImageCalculatorPython.delete_itkMinimumMaximumImageCalculatorIF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMinimumMaximumImageCalculatorIF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMinimumMaximumImageCalculatorIF2

        Create a new object of the class itkMinimumMaximumImageCalculatorIF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMinimumMaximumImageCalculatorIF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMinimumMaximumImageCalculatorIF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMinimumMaximumImageCalculatorIF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMinimumMaximumImageCalculatorIF2 in _itkMinimumMaximumImageCalculatorPython:
_itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIF2_swigregister(itkMinimumMaximumImageCalculatorIF2)

def itkMinimumMaximumImageCalculatorIF3_New():
    return itkMinimumMaximumImageCalculatorIF3.New()

class itkMinimumMaximumImageCalculatorIF3(itk.ITKCommonBasePython.itkObject):
    r"""Proxy of C++ itkMinimumMaximumImageCalculatorIF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMinimumMaximumImageCalculatorIF3_Pointer"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMinimumMaximumImageCalculatorIF3_Pointer"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIF3_Clone(self)

    def SetImage(self, _arg):
        r"""
        SetImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageF3 const *

        """
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIF3_SetImage(self, _arg)

    def ComputeMinimum(self):
        r"""ComputeMinimum(self)"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIF3_ComputeMinimum(self)

    def ComputeMaximum(self):
        r"""ComputeMaximum(self)"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIF3_ComputeMaximum(self)

    def Compute(self):
        r"""Compute(self)"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIF3_Compute(self)

    def GetMinimum(self):
        r"""GetMinimum(self) -> float"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIF3_GetMinimum(self)

    def GetMaximum(self):
        r"""GetMaximum(self) -> float"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIF3_GetMaximum(self)

    def GetIndexOfMinimum(self):
        r"""GetIndexOfMinimum(self) -> itkIndex3"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIF3_GetIndexOfMinimum(self)

    def GetIndexOfMaximum(self):
        r"""GetIndexOfMaximum(self) -> itkIndex3"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIF3_GetIndexOfMaximum(self)

    def SetRegion(self, region):
        r"""
        SetRegion(self, region)

        Parameters
        ----------
        region: itkImageRegion3 const &

        """
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIF3_SetRegion(self, region)
    __swig_destroy__ = _itkMinimumMaximumImageCalculatorPython.delete_itkMinimumMaximumImageCalculatorIF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMinimumMaximumImageCalculatorIF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMinimumMaximumImageCalculatorIF3

        Create a new object of the class itkMinimumMaximumImageCalculatorIF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMinimumMaximumImageCalculatorIF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMinimumMaximumImageCalculatorIF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMinimumMaximumImageCalculatorIF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMinimumMaximumImageCalculatorIF3 in _itkMinimumMaximumImageCalculatorPython:
_itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIF3_swigregister(itkMinimumMaximumImageCalculatorIF3)

def itkMinimumMaximumImageCalculatorISS2_New():
    return itkMinimumMaximumImageCalculatorISS2.New()

class itkMinimumMaximumImageCalculatorISS2(itk.ITKCommonBasePython.itkObject):
    r"""Proxy of C++ itkMinimumMaximumImageCalculatorISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMinimumMaximumImageCalculatorISS2_Pointer"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMinimumMaximumImageCalculatorISS2_Pointer"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorISS2_Clone(self)

    def SetImage(self, _arg):
        r"""
        SetImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageSS2 const *

        """
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorISS2_SetImage(self, _arg)

    def ComputeMinimum(self):
        r"""ComputeMinimum(self)"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorISS2_ComputeMinimum(self)

    def ComputeMaximum(self):
        r"""ComputeMaximum(self)"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorISS2_ComputeMaximum(self)

    def Compute(self):
        r"""Compute(self)"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorISS2_Compute(self)

    def GetMinimum(self):
        r"""GetMinimum(self) -> short"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorISS2_GetMinimum(self)

    def GetMaximum(self):
        r"""GetMaximum(self) -> short"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorISS2_GetMaximum(self)

    def GetIndexOfMinimum(self):
        r"""GetIndexOfMinimum(self) -> itkIndex2"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorISS2_GetIndexOfMinimum(self)

    def GetIndexOfMaximum(self):
        r"""GetIndexOfMaximum(self) -> itkIndex2"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorISS2_GetIndexOfMaximum(self)

    def SetRegion(self, region):
        r"""
        SetRegion(self, region)

        Parameters
        ----------
        region: itkImageRegion2 const &

        """
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorISS2_SetRegion(self, region)
    __swig_destroy__ = _itkMinimumMaximumImageCalculatorPython.delete_itkMinimumMaximumImageCalculatorISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMinimumMaximumImageCalculatorISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMinimumMaximumImageCalculatorISS2

        Create a new object of the class itkMinimumMaximumImageCalculatorISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMinimumMaximumImageCalculatorISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMinimumMaximumImageCalculatorISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMinimumMaximumImageCalculatorISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMinimumMaximumImageCalculatorISS2 in _itkMinimumMaximumImageCalculatorPython:
_itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorISS2_swigregister(itkMinimumMaximumImageCalculatorISS2)

def itkMinimumMaximumImageCalculatorISS3_New():
    return itkMinimumMaximumImageCalculatorISS3.New()

class itkMinimumMaximumImageCalculatorISS3(itk.ITKCommonBasePython.itkObject):
    r"""Proxy of C++ itkMinimumMaximumImageCalculatorISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMinimumMaximumImageCalculatorISS3_Pointer"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMinimumMaximumImageCalculatorISS3_Pointer"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorISS3_Clone(self)

    def SetImage(self, _arg):
        r"""
        SetImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageSS3 const *

        """
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorISS3_SetImage(self, _arg)

    def ComputeMinimum(self):
        r"""ComputeMinimum(self)"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorISS3_ComputeMinimum(self)

    def ComputeMaximum(self):
        r"""ComputeMaximum(self)"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorISS3_ComputeMaximum(self)

    def Compute(self):
        r"""Compute(self)"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorISS3_Compute(self)

    def GetMinimum(self):
        r"""GetMinimum(self) -> short"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorISS3_GetMinimum(self)

    def GetMaximum(self):
        r"""GetMaximum(self) -> short"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorISS3_GetMaximum(self)

    def GetIndexOfMinimum(self):
        r"""GetIndexOfMinimum(self) -> itkIndex3"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorISS3_GetIndexOfMinimum(self)

    def GetIndexOfMaximum(self):
        r"""GetIndexOfMaximum(self) -> itkIndex3"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorISS3_GetIndexOfMaximum(self)

    def SetRegion(self, region):
        r"""
        SetRegion(self, region)

        Parameters
        ----------
        region: itkImageRegion3 const &

        """
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorISS3_SetRegion(self, region)
    __swig_destroy__ = _itkMinimumMaximumImageCalculatorPython.delete_itkMinimumMaximumImageCalculatorISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMinimumMaximumImageCalculatorISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMinimumMaximumImageCalculatorISS3

        Create a new object of the class itkMinimumMaximumImageCalculatorISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMinimumMaximumImageCalculatorISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMinimumMaximumImageCalculatorISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMinimumMaximumImageCalculatorISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMinimumMaximumImageCalculatorISS3 in _itkMinimumMaximumImageCalculatorPython:
_itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorISS3_swigregister(itkMinimumMaximumImageCalculatorISS3)

def itkMinimumMaximumImageCalculatorIUC2_New():
    return itkMinimumMaximumImageCalculatorIUC2.New()

class itkMinimumMaximumImageCalculatorIUC2(itk.ITKCommonBasePython.itkObject):
    r"""Proxy of C++ itkMinimumMaximumImageCalculatorIUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMinimumMaximumImageCalculatorIUC2_Pointer"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMinimumMaximumImageCalculatorIUC2_Pointer"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIUC2_Clone(self)

    def SetImage(self, _arg):
        r"""
        SetImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageUC2 const *

        """
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIUC2_SetImage(self, _arg)

    def ComputeMinimum(self):
        r"""ComputeMinimum(self)"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIUC2_ComputeMinimum(self)

    def ComputeMaximum(self):
        r"""ComputeMaximum(self)"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIUC2_ComputeMaximum(self)

    def Compute(self):
        r"""Compute(self)"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIUC2_Compute(self)

    def GetMinimum(self):
        r"""GetMinimum(self) -> unsigned char"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIUC2_GetMinimum(self)

    def GetMaximum(self):
        r"""GetMaximum(self) -> unsigned char"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIUC2_GetMaximum(self)

    def GetIndexOfMinimum(self):
        r"""GetIndexOfMinimum(self) -> itkIndex2"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIUC2_GetIndexOfMinimum(self)

    def GetIndexOfMaximum(self):
        r"""GetIndexOfMaximum(self) -> itkIndex2"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIUC2_GetIndexOfMaximum(self)

    def SetRegion(self, region):
        r"""
        SetRegion(self, region)

        Parameters
        ----------
        region: itkImageRegion2 const &

        """
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIUC2_SetRegion(self, region)
    __swig_destroy__ = _itkMinimumMaximumImageCalculatorPython.delete_itkMinimumMaximumImageCalculatorIUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMinimumMaximumImageCalculatorIUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMinimumMaximumImageCalculatorIUC2

        Create a new object of the class itkMinimumMaximumImageCalculatorIUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMinimumMaximumImageCalculatorIUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMinimumMaximumImageCalculatorIUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMinimumMaximumImageCalculatorIUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMinimumMaximumImageCalculatorIUC2 in _itkMinimumMaximumImageCalculatorPython:
_itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIUC2_swigregister(itkMinimumMaximumImageCalculatorIUC2)

def itkMinimumMaximumImageCalculatorIUC3_New():
    return itkMinimumMaximumImageCalculatorIUC3.New()

class itkMinimumMaximumImageCalculatorIUC3(itk.ITKCommonBasePython.itkObject):
    r"""Proxy of C++ itkMinimumMaximumImageCalculatorIUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMinimumMaximumImageCalculatorIUC3_Pointer"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMinimumMaximumImageCalculatorIUC3_Pointer"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIUC3_Clone(self)

    def SetImage(self, _arg):
        r"""
        SetImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageUC3 const *

        """
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIUC3_SetImage(self, _arg)

    def ComputeMinimum(self):
        r"""ComputeMinimum(self)"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIUC3_ComputeMinimum(self)

    def ComputeMaximum(self):
        r"""ComputeMaximum(self)"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIUC3_ComputeMaximum(self)

    def Compute(self):
        r"""Compute(self)"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIUC3_Compute(self)

    def GetMinimum(self):
        r"""GetMinimum(self) -> unsigned char"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIUC3_GetMinimum(self)

    def GetMaximum(self):
        r"""GetMaximum(self) -> unsigned char"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIUC3_GetMaximum(self)

    def GetIndexOfMinimum(self):
        r"""GetIndexOfMinimum(self) -> itkIndex3"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIUC3_GetIndexOfMinimum(self)

    def GetIndexOfMaximum(self):
        r"""GetIndexOfMaximum(self) -> itkIndex3"""
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIUC3_GetIndexOfMaximum(self)

    def SetRegion(self, region):
        r"""
        SetRegion(self, region)

        Parameters
        ----------
        region: itkImageRegion3 const &

        """
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIUC3_SetRegion(self, region)
    __swig_destroy__ = _itkMinimumMaximumImageCalculatorPython.delete_itkMinimumMaximumImageCalculatorIUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMinimumMaximumImageCalculatorIUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMinimumMaximumImageCalculatorIUC3

        Create a new object of the class itkMinimumMaximumImageCalculatorIUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMinimumMaximumImageCalculatorIUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMinimumMaximumImageCalculatorIUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMinimumMaximumImageCalculatorIUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMinimumMaximumImageCalculatorIUC3 in _itkMinimumMaximumImageCalculatorPython:
_itkMinimumMaximumImageCalculatorPython.itkMinimumMaximumImageCalculatorIUC3_swigregister(itkMinimumMaximumImageCalculatorIUC3)

